embassy-nrf

Crates

git

Versions

nrf5340-app-s

Flavors

Status

Struct Status 

#[repr(transparent)]
pub struct Status(pub u32);
Status register.

Tuple Fields

0: u32

Implementations

Source

impl Status

pub const fn dpm(&self) -> bool

Deep power-down mode (DPM) status of external flash.

pub const fn set_dpm(&mut self, val: bool)

Deep power-down mode (DPM) status of external flash.

pub const fn ready(&self) -> bool

Ready status.

pub const fn set_ready(&mut self, val: bool)

Ready status.

pub const fn sreg(&self) -> u8

Value of external flash device Status Register. When the external flash has two bytes status register this field includes the value of the low byte.

pub const fn set_sreg(&mut self, val: u8)

Value of external flash device Status Register. When the external flash has two bytes status register this field includes the value of the low byte.